---
name: Gitea Generic Package
icon: https://raw.githubusercontent.com/go-gitea/gitea/main/assets/logo.svg
description: Plugin to Publish Artifacts to Gitea Generic Package Registry.
author: OCram85
tags: [Gitea, publish-package, container, build]
containerImage: ocram85/plugin-gitea-package
containerImageUrl: https://hub.docker.com/r/ocram85/plugin-gitea-package
url: https://codeberg.org/woodpecker-plugins/docker-buildx
---

# Overview

Woodpecker CI plugin to upload any file to the _Gitea Generic Package Registry_.

For details about the features and limits of the _Generic Package Registry_ their [docs](https://docs.gitea.com/usage/packages/generic).

## Settings

| Settings Name     | Default | Description                                 |
| ----------------- | ------- | ------------------------------------------- |
| `user`            | _none_  | Gitea user for basic auth                   |
| `password`        | _none_  | Password for basic auth                     |
| `debug`           | _none_  | Enables debug output if it's set to `true`. |
| `owner`           | _none_  | Package owner                               |
| `package_name`    | _none_  | The package name                            |
| `package_version` | _none_  | Package version                             |
| `file_source`     | _none_  | File source path for upload.                |
| `file_name`       | _none_  | Package file name                           |
| `update`          | `false` | Allow update existing package files         |

## Examples

```yaml
when:
  - event: [pull_request, tag, cron]
  - event: push
    branch:
      - ${CI_REPO_DEFAULT_BRANCH}

depends_on:
  - 'ci'

steps:
  next:
    image: ocram85/plugin-gitea-package:latest
    pull: true
    secrets: [gitea_user, gitea_passwd]
    settings:
      user:
        from_secret: gitea_user
      password:
        from_secret: gitea_passwd
      debug: 'true'
      owner: 'plugins'
      package_name: 'dummy_package'
      package_version: '0.1.0'
      file_source: './README.md'
      file_name: 'readme.md'
      update: 'true'
    when:
      event: pull_request
      branch: ${CI_REPO_DEFAULT_BRANCH}
```
